@@ -95,9 +95,7 @@ class ProxyInfo:
             return True
         elif self.failure > other.failure:
             return False
-        elif self.used_count < other.used_count:
-            return True
-        elif self.used_count > other.used_count:
+        elif other.used_count - self.used_count < -5:
             return False
         else:
             return self.response_time < other.response_time
