@@ -45,6 +45,7 @@ class ProxyPool:
                  fail_predicate_fn,
                  timeout=2,
                  connection_check_on_start=True,
+                 num_top_proxies=100,
                  verbose=False):
         """
         Start a self-organizing proxy pool which consistently re-order the proxies based on the failure rate and
@@ -89,24 +90,24 @@ class ProxyPool:
 
         self.__update_lock = RLock()
 
-        self.__init_pool(connection_check_on_start)
+        self.__init_pool(connection_check_on_start, num_top_proxies)
 
-    def __init_pool(self, check):
+    def __init_pool(self, check, num_top_proxies):
         print("initializing proxy pool...")
         print("http: {}, https: {}, sock4: {}, sock5: {}".format(len(self.__l_http),
                                                                  len(self.__l_https),
                                                                  len(self.__l_sock4),
                                                                  len(self.__l_sock5)))
-        self.__process_list(self.__l_http, "http", check)
-        self.__process_list(self.__l_https, "https", check)
-        self.__process_list(self.__l_sock4, "socks4", check)
-        self.__process_list(self.__l_sock5, "socks5", check)
+        self.__process_list(self.__l_http, "http", check, num_top_proxies)
+        self.__process_list(self.__l_https, "https", check, num_top_proxies)
+        self.__process_list(self.__l_sock4, "socks4", check, num_top_proxies)
+        self.__process_list(self.__l_sock5, "socks5", check, num_top_proxies)
 
         self.__pool_size = self.__pool.qsize()
 
         print("Done! Pool size [{}]".format(self.__pool_size))
 
-    def __process_list(self, in_list, type, check):
+    def __process_list(self, in_list, type, check, num_top_proxies):
         host_list = in_list.copy()
         size = len(host_list)
 
@@ -126,6 +127,10 @@ class ProxyPool:
                 results.append(result_each)
             sys.stdout.write("\rProgression for {0} = {1:.2f}%\n".format(type, 100.0))
 
+        if num_top_proxies:
+            results.sort()
+            results = results[:num_top_proxies]
+
         for result in results:
             self.__pool.put(result)
 
@@ -230,6 +235,7 @@ class ProxyPool:
             self.__pool.put(observable)
 
 
+
 def build_proxy_dict(folder="proxies", txt_file_names=None):
     if txt_file_names is None:
         txt_file_names = ["http", "https", "socks4", "socks5"]
@@ -248,7 +254,7 @@ def build_proxy_dict(folder="proxies", txt_file_names=None):
     return proxy_list_dict
 
 
-def build_proxy_pool(test_url, proxy_list_dict, pred, timeout=2, check_on_start=True, verbose=False):
+def build_proxy_pool(test_url, proxy_list_dict, pred, timeout=2, check_on_start=True, num_top_proxies=100, verbose=False):
     return ProxyPool(test_url,
                      proxy_list_dict['http'],
                      proxy_list_dict['https'],
@@ -257,4 +263,5 @@ def build_proxy_pool(test_url, proxy_list_dict, pred, timeout=2, check_on_start=
                      pred,
                      timeout=timeout,
                      connection_check_on_start=check_on_start,
+                     num_top_proxies=num_top_proxies,
                      verbose=verbose)
